@@ -28,17 +28,18 @@ extern "C" {
 #include <stdio.h>
 #include <stdarg.h>
 #include <stdint.h>
+#include <sys/types.h>
 
 /**
  * LIBFDISK_VERSION:
  *
  * Library version string
  */
-#define LIBFDISK_VERSION   "2.32.1"
+#define LIBFDISK_VERSION   "2.34.0"
 
 #define LIBFDISK_MAJOR_VERSION   2
-#define LIBFDISK_MINOR_VERSION   32
-#define LIBFDISK_PATCH_VERSION   1
+#define LIBFDISK_MINOR_VERSION   34
+#define LIBFDISK_PATCH_VERSION   0
 
 /**
  * fdisk_context:
@@ -143,7 +144,7 @@ struct fdisk_labelitem;
  * @FDISK_ASKTYPE_OFFSET:  ask for offset
  * @FDISK_ASKTYPE_WARN:  print warning message and errno
  * @FDISK_ASKTYPE_WARNX: print warning message
- * @FDISK_ASKTYPE_INFO: print infor message
+ * @FDISK_ASKTYPE_INFO: print info message
  * @FDISK_ASKTYPE_YESNO: ask Yes/No question
  * @FDISK_ASKTYPE_STRING: ask for string
  * @FDISK_ASKTYPE_MENU: ask for menu item
@@ -231,8 +232,12 @@ fdisk_sector_t fdisk_set_first_lba(struct fdisk_context *cxt, fdisk_sector_t lba
 fdisk_sector_t fdisk_get_last_lba(struct fdisk_context *cxt);
 fdisk_sector_t fdisk_set_last_lba(struct fdisk_context *cxt, fdisk_sector_t lba);
 fdisk_sector_t fdisk_get_nsectors(struct fdisk_context *cxt);
+
 const char *fdisk_get_devname(struct fdisk_context *cxt);
 int fdisk_get_devfd(struct fdisk_context *cxt);
+dev_t fdisk_get_devno(struct fdisk_context *cxt);
+const char *fdisk_get_devmodel(struct fdisk_context *cxt);
+
 
 unsigned int fdisk_get_geom_heads(struct fdisk_context *cxt);
 fdisk_sector_t fdisk_get_geom_sectors(struct fdisk_context *cxt);
@@ -614,7 +619,7 @@ extern int fdisk_bsd_link_partition(struct fdisk_context *cxt);
  * @BSD_LABELITEM_TYPE: type
  * @BSD_LABELITEM_DISK: disk
  * @BSD_LABELITEM_PACKNAME: packname
- * @BSD_LABELITEM_FLAGS: flags (removeable, ecc, badsect)
+ * @BSD_LABELITEM_FLAGS: flags (removable, ecc, badsect)
  * @BSD_LABELITEM_SECSIZE: Bytes/Sector
  * @BSD_LABELITEM_NTRACKS: Tracks/Cylinder
  * @BSD_LABELITEM_SECPERCYL: Sectors/Cylinder
@@ -726,7 +731,7 @@ extern int fdisk_gpt_set_partition_attrs(struct fdisk_context *cxt, size_t partn
  * @GPT_LABELITEM_FIRSTLBA: First Usable LBA
  * @GPT_LABELITEM_LASTLBA: Usable LBA
  * @GPT_LABELITEM_ALTLBA: Alternative LBA (backup header LBA)
- * @GPT_LABELITEM_ENTRIESLBA: Partitions entires array LBA
+ * @GPT_LABELITEM_ENTRIESLBA: Partitions entries array LBA
  * @GPT_LABELITEM_ENTRIESALLOC: Number of allocated entries in entries array
  *
  * GPT specific label items.
@@ -794,6 +799,7 @@ int fdisk_ask_number_set_result(struct fdisk_ask *ask, uint64_t result);
 uint64_t fdisk_ask_number_get_base(struct fdisk_ask *ask);
 uint64_t fdisk_ask_number_get_unit(struct fdisk_ask *ask);
 int fdisk_ask_number_set_relative(struct fdisk_ask *ask, int relative);
+int fdisk_ask_number_is_wrap_negative(struct fdisk_ask *ask);
 int fdisk_ask_number_inchars(struct fdisk_ask *ask);
 int fdisk_ask_partnum(struct fdisk_context *cxt, size_t *partnum, int wantnew);
 
